pub struct FileTreeData {
pub root_path: String,
pub root: FileNodeData,
}Expand description
A type for representing data about a file tree.
Fields
root_path: StringThe path to the root of this file tree.
root: FileNodeDataData about the root of this file tree.